
// FILE: assets/js/services/Common.js
function Common(MessageService, ScreenService, ZHPromise, templateManager){

    var self = this;

    this.widgetsToHide = {
        "parentWidgetName": ["childWidgetsName"],
        "repository_widget": ["repositoryLanguage"],
        "project_widget": ["projectRepository"]
    };

    function fixRowProperties(rows){
        rows.forEach(function(row){
            row.__is_new = false;
            row.__deleted = false;
        });
    }

    function updatedChildWidgetVisibility(widgetName){
        var container = templateManager.container;
        self.widgetsToHide[widgetName].forEach(function(name){
            var widget = container.getWidget(name);
            if(widget){
                widget.isVisible = !widget.isVisible;
            }
        });
    }

    function notificateSave(persistedRows){
        var messageParams = {
            persistedRows: persistedRows.length,
            name: ScreenService.i18n('row(s)')
        };
        MessageService.successNotificationByCode('ROW_SAVED', messageParams);
    }

    function getMode(widget){
        return widget.mode;
    }

    this.validateWidget = function(widget){
        var isValid = widget.isValid();
        if(!isValid){
            MessageService.alertNotificationByCode("REQ_FIElDS");
        }
        return isValid;
    };

    this.deleteRow = function(widget){
        var arrayOfRows = [widget.currentRow] || widget.getCheckedRows();
        fixRowProperties(arrayOfRows);
        if(getMode(widget) === 'view'){
            widget.dataSource.addCheckedRows(widget.currentRow);
            widget.list();
            ScreenService.closeSwipe();
        }
        widget.removeCheckedRows();
        widget.reload();
    };

    this.saveRow = function(widget){
        var currentRow = widget.currentRow;
        if(self.validateWidget(widget)){
            currentRow.__deleted = false;
            currentRow.__is_new = currentRow.__is_new || false;

            return widget.saveRow().then(function(response){
                if(!widget.parent && widget.isNewRow()){
                    updatedChildWidgetVisibility(widget.name);
                }
                notificateSave(response.dataset[Object.keys(response.dataset)[0]]);
                widget.reload();
            }).catch(function(e){
                ScreenService.errorNotification(e.data.error);
            });
        } else {
            return ZHPromise.reject();
        }
    };

    this.newRow = function(widget){
        if(!widget.parent){
            updatedChildWidgetVisibility(widget.name);
        }
        widget.newRow();
    };

    this.editRow = function(widget){
       widget.edit();
    };

    this.cancelAction = function(widget){
        if(getMode(widget) === 'edit' && !widget.isNewRow()){
            widget.view();
        } else {
            if(!widget.parent){
                updatedChildWidgetVisibility(widget.name);
            }
            widget.list();
            ScreenService.closeSwipe();
        }
        widget.reload();
    };

    function buildIdsToLoadInitialObject(selectFields){
		var idsToLoadObj = {};
		selectFields.forEach(function(fieldName){
			idsToLoadObj[fieldName] = {};
		});
		return idsToLoadObj;
	}

	this.loadSelectFields = function(widget, selectFields){
		var idsToLoadObj = buildIdsToLoadInitialObject(selectFields);

		widget.dataSource.data.forEach(function(row){
			selectFields.forEach(function(fieldName){
				var id = row[fieldName];
				if(id){
					idsToLoadObj[fieldName][id] = true;
				}
			});
		});

		selectFields.forEach(function(fieldName){
			var idsToLoad = Object.keys(idsToLoadObj[fieldName]);
			if(idsToLoad.length){
				var field = widget.getField(fieldName);
				var filters = [{
					"name": field.valueField,
					"operator": Query.IN,
					"value": idsToLoad
				}];
				field.dataSource.load(filters);
			}
		});
	};

}
Configuration(function(ContextRegister){
    ContextRegister.register('Common', Common);
});

// FILE: assets/js/services/FilterService.js
function FilterService(Query, ZHPromise){

    var filterType = {};

    var testFieldTemplate = function(field, templateName){
        return ~field.template.indexOf(templateName);
    };

    var buildFilterTypeMap = function(fields){
        fields.forEach(function(field){
            if(field.isVisible && field.aclIsVisible){
                var operator = "LIKE";
                var name = field.name;
                if(field.template){
                    if(testFieldTemplate(field, 'between-dates.html')){
                        operator = "BETWEEN";
                    } else if(testFieldTemplate(field, 'number.html') || testFieldTemplate(field, 'datetime.html')){
                        operator = "=";
                    } else if(field.outData && testFieldTemplate(field, 'select.html')){
                        name = field.outData[field.valueField];
                        operator = "=";
                    } else if(testFieldTemplate(field, 'select-multiple.html')){
                        operator = "IN";
                    }
                }
                filterType[name] = operator;
            }
        });
    };

    var filterTypeFlow = {
        "BETWEEN": function(query, value){
            query.between([value.start, value.end]);
        },
        "LIKE": function(query, value){
            query.like('%' + value + '%');
        },
        "=": function(query, value){
            query.equals(value);
        },
        "IN": function(query, value){
            query.in(value);
        }
    };

    this.buildFilter = function(fields, row){
        buildFilterTypeMap(fields);
        var query = Query.build();
        for(var key in row){
            if(row[key] && filterType[key] && (!Array.isArray(row[key]) || row[key].length > 0)){
                query.where(key);
                filterTypeFlow[filterType[key]](query, row[key]);
            }
        }
        return query.where();
    };

    this.parentFilter = function(parentWidget, childWidget){
        if(parentWidget && childWidget && childWidget.fields && childWidget.currentRow){
            parentWidget.innerFilters = parentWidget.innerFilters || parentWidget.dataSourceFilter || [];
            parentWidget.dataSourceFilter = parentWidget.innerFilters.concat(this.buildFilter(childWidget.fields, childWidget.currentRow));
            return parentWidget.reload();
        } else {
            var deferred = ZHPromise.defer();
            deferred.reject("Invalid params");
            return deferred;
        }
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('FilterService', FilterService);
});

// FILE: assets/js/controllers/LanguageController.js
/* global Configuration */
function LanguageController(Common){
	this.changeStatus = function(args){
		var row = args.row;
		var widget = args.owner.field.widget;
		widget.setCurrentRow(row);
		Common.saveRow(widget);
		widget.list();
	};
}

Configuration(function(ContextRegister){
	ContextRegister.register('LanguageController', LanguageController);
});

// FILE: assets/js/controllers/ProjectController.js
function ProjectController(templateManager, Common, ZhFilterPreferences, General, ScreenService, MessageService){
	var selectFields = ['ORGANIZATION', 'STRUCTURE', 'PROJECT_TYPE'];

	this.reloadOpenedChild = function(widget){
		var activeWidget = templateManager.container.getActiveWidget();
		// tem que arrumar um jeito de descobrir qual widget tá aberta no swipe
		if(activeWidget != widget){
			activeWidget.reload();
		}
	};

	this.loadSelectFields = function(widget){
		Common.loadSelectFields(widget, selectFields);
	};

	this.openFilter = function( widget ) {
		const managerField = widget.getField('MANAGER_ID');
		managerField.dataSource.reload().then( response => {
			const { dataset = { resource: []}} = response || {};
			const { resource = [] } = dataset;
			const [ FIRST_USER ] = resource;
			let MANAGER_ID = [];
			if(FIRST_USER && FIRST_USER.DEFAULT_USER == 'S') {
				MANAGER_ID = [ FIRST_USER.MANAGER_ID ];
				managerField.dataSource.addCheckedRows( FIRST_USER );
				managerField.dataSource.updateCheckedRows();
			}
			ZhFilterPreferences.openFilterWidget( widget, { MANAGER_ID } );
		});
	};

	this.selectedProject = function( widget ) {
		const PROJECT_ID = widget.currentRow.ID;
		const FIELD_PROJECT_LANGUAGE = widget.getField('PROJECT_LANGUAGE');
		const FILTER_PROJECT_ID = {
			name: "PROJECT_ID",
			operator: "=",
			value: PROJECT_ID
		};
		let PROJECT_LANGUAGE = '';
		FIELD_PROJECT_LANGUAGE.dataSource.load([FILTER_PROJECT_ID]).then( response => {
			FIELD_PROJECT_LANGUAGE.dataSource.data = response.dataset.languagesByProjectId;
			PROJECT_LANGUAGE = response.dataset.languagesByProjectId.map( language => language.ID);
			widget.currentRow.PROJECT_LANGUAGE = PROJECT_LANGUAGE;
		}); 
	};

	this.openPopupUpdateLanguages = function( widget ){
		const WDGT_UPDATE_LANGUAGES = templateManager.container.getWidget('UPDATE_LANGUAGES_POPUP');
		ScreenService.openPopup(WDGT_UPDATE_LANGUAGES);
	};

	this.copyToClipboard = function(){
		if(navigator && event && event.currentTarget) {
			const [ SPAN_ELEMENT ] = event.currentTarget.getElementsByTagName('SPAN');
			if( SPAN_ELEMENT && SPAN_ELEMENT.textContent ) {
				navigator.clipboard.writeText(SPAN_ELEMENT.textContent);
				MessageService.successNotificationByCode("COPIED_SUCCESS_CLIPBOARD", 2000, {PARAM: SPAN_ELEMENT.textContent});
			}
		}
	};

}
Configuration(function(ContextRegister) {
	ContextRegister.register('ProjectController', ProjectController);
});

// FILE: assets/js/controllers/ProjectRepositoryController.js
function ProjectRepositoryController(templateManager, ScreenService, MessageService, Common, General){
	var selectFields = ['REPOSITORY_ID'];

	this.edit = function(widget){
		widget.edit();
		var dataSourceFilter = [{
			name: "IS_ACTIVE",
			operator: "=",
			value: "Y"
		}];
		var languagesField = widget.getField('LANGUAGES');
		var defaultLanguageField = widget.getField('DEFAULT_LANGUAGE_NAME');
		languagesField.dataSourceFilter = dataSourceFilter;
		defaultLanguageField.dataSourceFilter = dataSourceFilter;
	};

	function cancelEdit(widget){
		var languagesField = widget.getField('LANGUAGES');
		var defaultLanguageField = widget.getField('DEFAULT_LANGUAGE_NAME');
		languagesField.dataSourceFilter = [];
		defaultLanguageField.dataSourceFilter = [];
	}

	this.cancelEdit = function(widget){
		cancelEdit(widget);
		widget.view();
		widget.reload();
	};

	function getCurrentProjectID(){
		var widget = templateManager.container && templateManager.container.getWidget('project_widget');
		var currentRow = widget && widget.currentRow || {};
		return currentRow.ID;
	}
	this.getCurrentProjectID = getCurrentProjectID;

	this.saveRow = function(widget){
		widget.saveRow().then(function(){
			cancelEdit(widget);
			ScreenService.closeSwipe();
			MessageService.successNotificationByCode('SAVE_SUCCESS');
			widget.parent.reload();
		}).catch(function(){
			MessageService.errorNotificationByCode('SAVE_FAIL');
		});
	};

	this.openAddWidget = function(widget){
		var addWidget = templateManager.container.getWidget('add_repository_popup');
		var projectWidget = templateManager.container.getWidget('project_widget');
		const { ID: PROJECT_ID } = projectWidget.currentRow;
		const repositoryField = addWidget.getField('REPOSITORY');
		let projectFilter = repositoryField.dataSourceFilter.find(filter => filter.name === 'PROJECT_ID');
		if( projectFilter ) {
			projectFilter.value = PROJECT_ID;
			repositoryField.reload();

		}
		addWidget.reopenWidget = widget.name;
		addWidget.newRow();
		ScreenService.openPopup(addWidget);
		var repositoryIds = widget.dataSource.data.map(function(row){
			return row.REPOSITORY_ID;
		});
		if(repositoryIds.length){
			addWidget.dataSourceFilter = [
				{
					name: "ID",
					operator: "NOT_IN",
					value: repositoryIds
				}
			];
		} else {
			addWidget.dataSourceFilter = [];
		}
	};

	function closePopup(widget){
		ScreenService.closePopup();
		if(widget.reopenWidget){
			var lastActiveWidget = templateManager.container.getWidget(widget.reopenWidget);
			lastActiveWidget.activate();
		}
		widget.reload();
	}
	this.closePopup = closePopup;

	this.deleteProjectRepository = function(widget){
		widget.removeCheckedRows();
		widget.reload();
	};

	function handleSsh( link ){
		const TYPE = '(?<TYPE>[^@]+)';
		const HOST = '(?<HOST>[^:]+)';
		const GROUP = '(?<GROUP>[^\\/]+)';
		const REPOSITORY = '(?<REPOSITORY>\\w+)';
		const PATTERN = new RegExp(`${TYPE}?@${HOST}?:${GROUP}\/${REPOSITORY}`, 'gi');
		const { groups = {type: "", host: "", group: "", repository: ""}} = PATTERN.exec(link) || {};
		return groups;
	}
	function handleHttp( link ){
		const PROTOCOL = '(?<PROTOCOL>(\\bhttp\\b|\\bhttps\\b))';
		const USER = '(?<USER>[^@]+)';
		const HOST = '(?<HOST>[^\/]+)';
		const GROUP = '(?<GROUP>[^\/]+)';
		const REPOSITORY = '(?<REPOSITORY>\\w+)';
		const PATTERN = new RegExp(`${PROTOCOL}:\/\/${USER}@${HOST}\/${GROUP}\/${REPOSITORY}`, 'gi');
		const { groups = {protocol: "", user: "", type: "", host: "", group: "", repository: ""}} = PATTERN.exec(link) || {};
		return groups;
	}

	this.afterLoadRepositories = function( widget ){
		widget.dataSource.data.forEach( repository => {
			let link = repository.URL;
			let result = {};
			if(typeof link == 'string') {
				if(link.toLowerCase().includes('http')) {
					result = handleHttp( link );
				} else {
					result = handleSsh( link );
				}
			} 
			let {
				GROUP = '',
				HOST = '',
				REPOSITORY = ''
			} = result;
			Object.assign(repository, {GROUP, HOST, REPOSITORY});
		});
	};

	this.updateLanguagesToTranslate = function( widget ){
		let defaultLanguage = null;
		const REPOSITORY_LIST = [];
		const isEqualDefaultLanguage = widget.dataSource.getCheckedRows().every( repository => {
			if(defaultLanguage == null) defaultLanguage = repository.DEFAULT_LANGUAGE;
			REPOSITORY_LIST.push(repository.REPOSITORY_ID);
			return repository.DEFAULT_LANGUAGE == defaultLanguage;
		});

		if( isEqualDefaultLanguage ) {
			const POPUP_UPDATE_LANGUAGES = templateManager.container.getWidget('UPDATE_LANGUAGES_POPUP');
			POPUP_UPDATE_LANGUAGES.currentRow.REPOSITORY_LIST = REPOSITORY_LIST;
			POPUP_UPDATE_LANGUAGES.currentRow.DEFAULT_LANGUAGE = defaultLanguage;
			POPUP_UPDATE_LANGUAGES.currentRow.LANGUAGES = [];
			ScreenService.openPopup(POPUP_UPDATE_LANGUAGES);
		} else {
			MessageService.showMessageByCode("DIFFERENT_DEFAULT_LANGUAGES");
		}
	};

	this.updateLanguagesProject = function(){
		const widgetPopup = templateManager.container.getWidget('UPDATE_LANGUAGES_POPUP');
		const { REPOSITORY_LIST, LANGUAGES} = widgetPopup.currentRow;
		if(!widgetPopup.isValid()) return;
		const confirmOperation = OPERATION => {
			General.callRestEngine('/projectRepository/updateLanguages', 'Row', {REPOSITORY_LIST, LANGUAGES, OPERATION}).then( _ => {
				MessageService.showMessageByCode("SAVE_SUCCESS", null, {type: 'success'});
				ScreenService.closePopup();
			}).catch(error => {
				console.error(error);
				MessageService.showMessageByCode("SAVE_FAIL", null, {type: 'error'});
			});
		};
		MessageService.showCustomDialogByCode("QUESTION_UPDATE_LANGUAGES", null, {
			actions: [
				{
					label: "Include",
					code: _ => confirmOperation('INCLUDE')
				},
				{
					label: "Overwrite",
					code: _ => confirmOperation('OVERWRITE')
				},
				{
					label: "Cancel",
					code: _ => {}
				}
			]
		});
	};

	this.beforeOpenRepositoryListField = function( field ) {
		let firstLoad = false;
		let { DEFAULT_LANGUAGE } = field.widget.currentRow;
		if(!field.oldDataSourceFilter) {
			field.oldDataSourceFilter = angular.copy(field.dataSourceFilter);
			firstLoad = true;
		}
		let filterId = field.dataSourceFilter.find( filter => filter.name === 'ID');
		if( filterId ) {
			filterId.value = DEFAULT_LANGUAGE;
		} else {
			field.dataSourceFilter.push({
				name: "ID",
				operator: "<>",
				value: DEFAULT_LANGUAGE
			});
		}
		if(firstLoad || !angular.equals(field.oldDataSourceFilter, field.dataSourceFilter)) {
			field.oldDataSourceFilter = angular.copy(field.dataSourceFilter);
			field.reload();
		}
	};

	this.addRepositories = function( popupWidget ){
		const { REPOSITORY = [] } = popupWidget.currentRow;
		const PROJECT_ID = getCurrentProjectID();
		if(Array.isArray(REPOSITORY) && REPOSITORY.length){
			const REPOSITORY_TAB = templateManager.container.getWidget('projectRepository');
			var newRows = REPOSITORY.map( REPOSITORY_ID => {
				return {
					ID: null,
					IS_ACTIVE: 'Y',
					PROJECT_ID,
					REPOSITORY_ID,
					CREATED: null,
					CREATED_BY: null,
					UPDATED: null,
					UPDATED_BY: null,
					__is_new: true,
					changed: true
				};
			});
			REPOSITORY_TAB.dataSource.data = REPOSITORY_TAB.dataSource.data.concat(newRows);
			REPOSITORY_TAB.dataSource.save().then(function(){
				closePopup(popupWidget);
				MessageService.successNotificationByCode('SAVE_SUCCESS');
			}).catch(function(){
				closePopup(popupWidget);
				MessageService.errorNotificationByCode('SAVE_FAIL');
			});
		}
	};

}
Configuration(function(ContextRegister) {
	ContextRegister.register('ProjectRepositoryController', ProjectRepositoryController);
});

// FILE: assets/js/controllers/RepositoryController.js
function RepositoryController(ScreenService, MessageService, Common, templateManager){
	function clearLanguagesFilter(languagesField){
		languagesField.dataSourceFilter = languagesField.dataSourceFilter.filter(function(filter){
			return filter.name != 'ID';
		});
		languagesField.reload();
	}

	function updateLanguagesFilter(languagesField, defaultLanguage){
		if(defaultLanguage){
			var filter = languagesField.dataSourceFilter.filter(function(filter){
				return filter.name == 'ID';
			})[0];

			if(filter){
				filter.value = defaultLanguage;
			} else {
				filter = {
					name: "ID",
					operator: "<>",
					value: defaultLanguage
				};
				languagesField.dataSourceFilter.push(filter);
			}
			languagesField.reload();
		} else {
			clearLanguagesFilter(languagesField);
		}
	}

	this.updateLanguagesField = function updateLanguagesField(widget){
		var defaultLanguage = widget.currentRow && widget.currentRow.DEFAULT_LANGUAGE;
		var languagesField = widget.getField('LANGUAGES');
		var languagesFieldValue = languagesField.value() || [];
		languagesFieldValue = languagesFieldValue.filter(function(value){ return value != defaultLanguage; });
		languagesField.value(languagesFieldValue);
		updateLanguagesFilter(languagesField, defaultLanguage);
	};

	this.editRow = function(widget){
		var defaultLanguage = widget.currentRow && widget.currentRow.DEFAULT_LANGUAGE;
		var languagesField = widget.getField('LANGUAGES');
		widget.edit();
		updateLanguagesFilter(languagesField, defaultLanguage);
	};

	this.saveRow = function(widget){
		if(widget.isValid()){
			widget.saveRow().then(function(response){
				widget.currentRow.ID = Util.getNestedProperty(response, ['dataset', 'repository', widget.currentRow.URL]);
				ScreenService.closeSwipe();
				clearLanguagesFilter(widget.getField('LANGUAGES'));
				MessageService.successNotificationByCode('SAVE_SUCCESS');
				widget.reload();
			}).catch(function(){
				MessageService.errorNotificationByCode('SAVE_FAIL');
			});
		}
	};

	this.openAddWidget = function(widget){
		var addWidget = templateManager.container.getWidget('add_repository');
		addWidget.reopenWidget = widget.name;
		ScreenService.openPopup(addWidget);
		addWidget.reload();
	};

	function closePopup(widget){
		ScreenService.closePopup();
		if(widget.reopenWidget){
			var lastActiveWidget = templateManager.container.getWidget(widget.reopenWidget);
			lastActiveWidget.activate();
		}
	}
	this.closePopup = closePopup;

	this.addRow = function(popupWidget, row){
		closePopup(popupWidget);
		var widget = templateManager.container.getWidget('repository_widget');
		var field = widget.getField('URL');
		field.defaultValue = row.URL;
		widget.currentRow = {};
		widget.newRow();
	};

	this.cancelAction = function cancelAction(widget){
		clearLanguagesFilter(widget.getField('LANGUAGES'));

		delete widget.currentRow.changed;
		Common.cancelAction(widget);
	};

	this.changeFieldsVisibility = function(row, widget){
		var showNewFields = row.NEW_STRUCTURE === 'Y';
		var pathField = widget.getField('FRONT_PATH');
		pathField.label = showNewFields ? 'BIRT Path' : 'Front Path';
		pathField.validations.required = !showNewFields;
		widget.getField('MESSAGES_FILE').isVisible = showNewFields;
		widget.getField('MESSAGES_STRUCTURE').isVisible = showNewFields;
		widget.getField('WORDS_PATH').isVisible = showNewFields;
	};

	this.inactivateRepository = function( widget ){
		widget.currentRow.changed = true;
		widget.currentRow.IS_ACTIVE = "N";
		widget.saveRow().then(() => {
			MessageService.successNotificationByCode("SAVE_SUCCESS");
			ScreenService.closeSwipe();
			widget.reload();
		}, (error) => {
			console.error(error);
			MessageService.errorNotificationByCode("SAVE_FAIL");
		});
	};
}
Configuration(function(ContextRegister) {
	ContextRegister.register('RepositoryController', RepositoryController);
});

// FILE: assets/js/controllers/RepositoryLanguageController.js
/* global Configuration */
function RepositoryLanguageController(ScreenService, Common){

	var self = this;
	var LANGUAGE_FIELD = 'LANGUAGE_ID';
	var REPOSITORY_ID_BACKUP;

	function getField(widget, name){
		return widget.getField(name);
	}

	function returnNotUsefulLanguageIds(field){
		var languageIds = [];

		field.widget.dataSource.data.forEach(function(row){
			if(row.LANGUAGE_ID !== "" && languageIds.indexOf(row.LANGUAGE_ID) == -1){
				languageIds.push(row.LANGUAGE_ID);
			}
		});

		languageIds.push(field.widget.parent.currentRow.DEFAULT_LANGUAGE);
		return languageIds;
	}

	function filterSelectData(field){
		var notUsefulLanguageIds = returnNotUsefulLanguageIds(field);
		field.dataSourceFilter = [
			{
				"name": "IS_ACTIVE",
				"operator": "=",
				"value": "Y"
			}
		];
		if(notUsefulLanguageIds.length > 0){
			field.dataSourceFilter.push(
				{
					"name": "ID",
					"operator": "NOT_IN",
					"value":notUsefulLanguageIds
				}
			);
		}
		field.reload();
	}

	this.newRow = function(widget){
		Common.newRow(widget);
		filterSelectData(getField(widget, LANGUAGE_FIELD));
		widget.reload();
	};

	this.resetFilter = function(widget){
		var field = getField(widget, LANGUAGE_FIELD);
		field.dataSourceFilter = [
			{
				"name": "IS_ACTIVE",
				"operator": "=",
				"value": "Y"
			}
		];
		field.reload();
	};

	this.setRepositoryID = function(widget){
		REPOSITORY_ID_BACKUP = widget.currentRow.ID;
	};

	this.getRepositoryID = function(){
		return REPOSITORY_ID_BACKUP;
	};

	this.saveRow = function(widget){
		widget.currentRow.REPOSITORY_ID = REPOSITORY_ID_BACKUP;
		Common.saveRow(widget).then(function(){
			self.resetFilter(widget);
			widget.reload();
			ScreenService.closeSwipe();
		});
	};

	this.deleteRow = Common.deleteRow;
	this.cancelAction = Common.cancelAction;
}
Configuration(function(ContextRegister) {
	ContextRegister.register('RepositoryLanguageController', RepositoryLanguageController);
});

// FILE: assets/js/controllers/TranslateWordsController.js
function TranslateWordsController(templateManager, ScreenService, MessageService){

    function notificateSave(name, message, pluralName){
        if(message.dataset){
            var key = Object.keys(message.dataset)[0];
            var persistedRows = message.dataset[key].length;
            if(persistedRows > 1){
                name = pluralName || name + 's';
            }
            MessageService.successNotificationByCode('ROW_SAVED', 0, {"persistedRows": persistedRows, "name": name });
        }
    }

    function editRow(widget, currentRow){
        if(widget.name !== "zhFilterPreferencesSelectConditions"){
            currentRow.STATUS = 'A';
        }
    }
    this.editRow = editRow;

    this.saveDetailRow = function saveDetailRow(widget){
        editRow(widget, widget.currentRow);
        saveWords(widget).then(function(){
            widget.view();
            ScreenService.closeSwipe();
            widget.reload();
        });
    };

    function saveWords(widget){
        return widget.dataSource.save()
            .then(function(){
                widget.commitInlineEdit();
                widget.reload();
            })
            .catch(function(response){
                ScreenService.showMessage(response.data.error);
            });
    }
    this.saveWords = saveWords;

    this.saveCheckedRows = function saveCheckedRows(widget){
        var checkedRows = widget.getCheckedRows();

        checkedRows = checkedRows.filter(function(row) {
            if(row.STATUS == 'T') {
                row.changed = true;
                row.STATUS = 'A';
                return true;
            }
            return false;
        });

        widget.dataSource.save().then(function(message){
            checkedRows.forEach(function(row){
                row.changed = false;
            });
            notificateSave("word", message);
            widget.unSelectAll();
            widget.activate();
            ScreenService.closeSwipe();
            widget.reload();
        }, function(response){
            ScreenService.showMessage(response.data.error);
        });
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('TranslateWordsController', TranslateWordsController);
});